pub type ZMPoly = SparseMultivariatePolynomial<IntegerDomain, Lex>;Expand description
Alias for sparse polynomials over the integers with lexicographic order.
Aliased Type
pub struct ZMPoly { /* private fields */ }pub type ZMPoly = SparseMultivariatePolynomial<IntegerDomain, Lex>;Alias for sparse polynomials over the integers with lexicographic order.
pub struct ZMPoly { /* private fields */ }