pub struct MatrixOrder { /* private fields */ }Expand description
Matrix ordering: compare monomials by multiplying exponent vectors by an integer matrix and comparing the results lexicographically.
Given an $n \times n$ matrix $M$, monomial $\alpha > \beta$ iff $M\alpha >_{\text{lex}} M\beta$. This generalizes all standard orderings and is particularly useful for constructing elimination orderings.
Example
use ocas_poly::sparse::{MatrixOrder, MonomialOrder};
// 2×2 identity matrix = Lex order
let ord = MatrixOrder::new(vec![vec![1, 0], vec![0, 1]]);
assert_eq!(ord.cmp(&[1, 0], &[0, 1]), std::cmp::Ordering::Greater);Implementations
Sourceimpl MatrixOrder
impl MatrixOrder
Sourcepub fn elimination_order(elim_vars: usize, n_vars: usize) -> Self
pub fn elimination_order(elim_vars: usize, n_vars: usize) -> Self
Create an elimination ordering that eliminates the first elim_vars
variables. Equivalent to BlockOrder([elim_vars in Lex, rest in Grevlex]) but expressed as a weight matrix.