pub struct WeightOrder { /* private fields */ }Expand description
Weighted ordering: compare by $\sum_i w_i \cdot e_i$ descending.
The weight vector is stored at construction time, enabling arbitrary elimination orderings that cannot be expressed as zero-sized types.
Example
use ocas_poly::sparse::{MonomialOrder, WeightOrder};
use smallvec::smallvec;
let ord = WeightOrder::new(smallvec![2, 1]);
// [1,0] → weight 2, [0,1] → weight 1 → [1,0] is "larger"
assert_eq!(ord.cmp(&[1, 0], &[0, 1]), std::cmp::Ordering::Less);Implementations