Polynomial factorization algorithms.
This module groups square-free factorization with complete factorization
over finite fields (finite_field) and, for lifting back to the integers,
Hensel lifting (hensel).
The top-level entry point for factoring a univariate polynomial over
$\mathbb{Z}$ is DenseUnivariatePolynomial::factor,
and over a finite field
factor_over_finite_field.
Modules
- finite_
field - Factorization over finite fields $\mathbb{F}_p$.
- hensel
- Hensel lifting and Zassenhaus factor combination over $\mathbb{Z}$.
- multivariate
- Multivariate polynomial factorization.
Type Aliases
- Factors
- Result of a complete factorization: list of (factor, multiplicity) pairs where each factor is irreducible (or, over the integers, primitive and irreducible over $\mathbb{Q}$).
- Square
Free Factors - Result of a square-free factorization: list of (factor, multiplicity) pairs.